@@ -1,7 +1,12 @@
 use Mojo::Util qw(url_escape);
 sub Mojo::Weixin::_sync {
     my $self = shift;
-    return if ($self->_synccheck_running or $self->_sync_running);
+    #if($self->_synccheck_running or $self->_sync_running){
+    #if($self->_sync_running){
+    #    $self->debug("消息处理程序进行中，避免重复运行(2)");
+    #    return;
+    #}
+    $self->debug("接收消息...");
     $self->_sync_running(1);
     my $api = 'https://'. $self->domain . '/cgi-bin/mmwebwx-bin/webwxsync';
     my @query_string = (
@@ -16,16 +21,12 @@ sub Mojo::Weixin::_sync {
     };
     my $callback = sub{
         my ($json,$ua,$tx) = @_;
-        $self->emit(receive_raw_message=>$tx->res->body,$json);
+        my $status  = 1;
+        if(not defined $json){$status = 0;}
+        elsif(defined $json and $json->{BaseResponse}{Ret} == -1){$status = 0}
         $self->_sync_running(0);
-        if(defined $json and $json->{BaseResponse}{Ret} == -1){#对于 -1 的消息做延迟处理，防止刷屏
-            $self->timer(5,sub{
-                $self->emit("sync_over",$json);
-            }); 
-        }
-        else{
-            $self->emit("sync_over",$json);
-        }
+        $self->emit(receive_raw_message=>$tx->res->body,$json);
+        $self->emit("sync_over",$json,$status);
     };
     $self->http_post($self->gen_url($api,@query_string),{Referer=>'https://' . $self->domain .  '/',json=>1},json=>$post,$callback);
 }
