@@ -57,17 +57,23 @@ sub _http_request{
     my $method = shift;
     my %opt = (
         json                =>  0,
-        retry_times         =>  $self->ua_retry_times,
+        ua_retry_times      =>  $self->ua_retry_times,
+        #ua_connect_timeout  =>  $self->ua_connect_timeout,
+        #ua_request_timeout  =>  $self->ua_request_timeout,
+        #ua_inactivity_timeout => $self->ua_inactivity_timeout,
         ua_debug            =>  $self->ua_debug,
         ua_debug_res_body   =>  $self->ua_debug_res_body,
         ua_debug_req_body   =>  $self->ua_debug_req_body
     );
     if(ref $_[1] eq "HASH"){#with header or option
         $opt{json} = delete $_[1]->{json} if defined $_[1]->{json};
-        $opt{retry_times} = delete $_[1]->{retry_times} if defined $_[1]->{retry_times};
+        $opt{ua_retry_times} = delete $_[1]->{ua_retry_times} if defined $_[1]->{ua_retry_times};
         $opt{ua_debug}          = delete $_[1]->{ua_debug} if defined $_[1]->{ua_debug};
         $opt{ua_debug_res_body} = delete $_[1]->{ua_debug_res_body} if defined $_[1]->{ua_debug_res_body};
         $opt{ua_debug_req_body} = delete $_[1]->{ua_debug_req_body} if defined $_[1]->{ua_debug_req_body};
+        $opt{ua_connect_timeout} = delete $_[1]->{ua_connect_timeout} if defined $_[1]->{ua_connect_timeout};
+        $opt{ua_request_timeout} = delete $_[1]->{ua_request_timeout} if defined $_[1]->{ua_request_timeout};
+        $opt{ua_inactivity_timeout} = delete $_[1]->{ua_inactivity_timeout} if defined $_[1]->{ua_inactivity_timeout};
     }
     if(ref $_[-1] eq "CODE"){
         my $cb = pop;
@@ -87,8 +93,22 @@ sub _http_request{
     }
     else{
         my $tx;
-        for(my $i=0;$i<=$opt{retry_times};$i++){
-            $tx = $self->ua->$method(@_);
+        for(my $i=0;$i<=$opt{ua_retry_times};$i++){
+            if($opt{ua_connect_timeout} or  $opt{ua_request_timeout} or $opt{ua_inactivity_timeout}){
+                my $connect_timeout = $self->ua->connect_timeout;
+                my $request_timeout = $self->ua->request_timeout;
+                my $inactivity_timeout = $self->ua->inactivity_timeout;
+                $self->ua->connect_timeout($opt{ua_connect_timeout}) if $opt{ua_connect_timeout};
+                $self->ua->request_timeout($opt{ua_request_timeout}) if $opt{ua_request_timeout};
+                $self->ua->inactivity_timeout($opt{ua_inactivity_timeout}) if $opt{ua_inactivity_timeout};
+                $tx = $self->ua->$method(@_);
+                $self->ua->connect_timeout($connect_timeout)
+                        ->request_timeout($request_timeout)
+                        ->inactivity_timeout($inactivity_timeout);
+            }
+            else{
+                $tx = $self->ua->$method(@_);
+            }
             _ua_debug($self,$ua,$tx,\%opt,1) if $opt{ua_debug};;
             $self->save_cookie();
             if(defined $tx and $tx->success){
